# Atome PyPi

Get your energy consumption data from Atome, a Linky-compatible device made by Total/Direct-Energie.

### Installing


```
pip install pyatome
```



## Running the tests


### Break down into end to end tests


## Side notes

As there is no official documentation on the API, I had to reverse-engineer what is the one used in the Atome IOS APP.
This module will cover only the /api path, and not crawl the pages generated by the "graph-query" paths.


## Contributing

Any contribution is welcome, considering the number of features the API provides, there is room for improvement!

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/baqs/pyAtome/tags). 

## Authors

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

## Acknowledgments

* Thanks to k20human for the original inspiration with https://github.com/k20human/domoticz-atome

